
/* Generated data (by glib-mkenums) */

#ifndef __IDE_ENUMS_H__
#define __IDE_ENUMS_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "./buffers/ide-buffer.h" */
GType ide_buffer_line_flags_get_type (void);
#define IDE_TYPE_BUFFER_LINE_FLAGS (ide_buffer_line_flags_get_type ())

/* enumerations from "./buildsystem/ide-build-log.h" */
GType ide_build_log_stream_get_type (void);
#define IDE_TYPE_BUILD_LOG_STREAM (ide_build_log_stream_get_type ())

/* enumerations from "./buildsystem/ide-build-pipeline.h" */
GType ide_build_phase_get_type (void);
#define IDE_TYPE_BUILD_PHASE (ide_build_phase_get_type ())

/* enumerations from "./devices/ide-device.h" */
GType ide_device_error_get_type (void);
#define IDE_TYPE_DEVICE_ERROR (ide_device_error_get_type ())

/* enumerations from "./diagnostics/ide-diagnostic.h" */
GType ide_diagnostic_severity_get_type (void);
#define IDE_TYPE_DIAGNOSTIC_SEVERITY (ide_diagnostic_severity_get_type ())

/* enumerations from "./doap/ide-doap.h" */
GType ide_doap_error_get_type (void);
#define IDE_TYPE_DOAP_ERROR (ide_doap_error_get_type ())

/* enumerations from "./files/ide-indent-style.h" */
GType ide_indent_style_get_type (void);
#define IDE_TYPE_INDENT_STYLE (ide_indent_style_get_type ())

/* enumerations from "./highlighting/ide-highlighter.h" */
GType ide_highlight_result_get_type (void);
#define IDE_TYPE_HIGHLIGHT_RESULT (ide_highlight_result_get_type ())

/* enumerations from "./runtimes/ide-runtime.h" */
GType ide_runtime_error_get_type (void);
#define IDE_TYPE_RUNTIME_ERROR (ide_runtime_error_get_type ())

/* enumerations from "./sourceview/ide-source-view.h" */
GType ide_source_view_mode_type_get_type (void);
#define IDE_TYPE_SOURCE_VIEW_MODE_TYPE (ide_source_view_mode_type_get_type ())
GType ide_source_view_theatric_get_type (void);
#define IDE_TYPE_SOURCE_VIEW_THEATRIC (ide_source_view_theatric_get_type ())
GType ide_source_view_movement_get_type (void);
#define IDE_TYPE_SOURCE_VIEW_MOVEMENT (ide_source_view_movement_get_type ())

/* enumerations from "./symbols/ide-symbol.h" */
GType ide_symbol_kind_get_type (void);
#define IDE_TYPE_SYMBOL_KIND (ide_symbol_kind_get_type ())
GType ide_symbol_flags_get_type (void);
#define IDE_TYPE_SYMBOL_FLAGS (ide_symbol_flags_get_type ())

/* enumerations from "./threading/ide-thread-pool.h" */
GType ide_thread_pool_kind_get_type (void);
#define IDE_TYPE_THREAD_POOL_KIND (ide_thread_pool_kind_get_type ())

/* enumerations from "./transfers/ide-transfer.h" */
GType ide_transfer_error_get_type (void);
#define IDE_TYPE_TRANSFER_ERROR (ide_transfer_error_get_type ())

/* enumerations from "./vcs/ide-vcs-config.h" */
GType ide_vcs_config_type_get_type (void);
#define IDE_TYPE_VCS_CONFIG_TYPE (ide_vcs_config_type_get_type ())

/* enumerations from "./workbench/ide-layout-stack-split.h" */
GType ide_layout_grid_split_get_type (void);
#define IDE_TYPE_LAYOUT_GRID_SPLIT (ide_layout_grid_split_get_type ())
G_END_DECLS

#endif /* __IDE_ENUMS_H__ */

/* Generated data ends here */

